pub struct Attr {
pub attr_type: Id,
pub value: String,
pub bannable: bool,
pub not_identifying: bool,
pub not_addable: bool,
}Fields
attr_type: Idvalue: StringActual value of this attribute, in a format that is Type dependent.
bannable: boolnot_identifying: boolWhether the attribute is not identifying. We use the negation so that the default will be that the attribute is identifying, which most attributes are.
not_addable: boolWhether this particular attribute can not be added to a user account.
A pubhubs card attribute obtained via Yivi disclosure is not addable, for example.
Implementations
Sourceimpl Attr
impl Attr
Sourcepub fn id(&self, secret: impl DigestibleSecret) -> Id
pub fn id(&self, secret: impl DigestibleSecret) -> Id
Derives an identifier for this attribute from Attr::value and Attr::attr_type,
and the given digestible secret.