Type

Struct Type 

pub struct Type {
    pub id: Id,
    pub handles: Handles,
    pub bannable: bool,
    pub identifying: bool,
    pub sources: Vec<SourceDetails>,
    pub not_addable_by_default: bool,
}

Fields

id: Id

Immutable

handles: Handles

For referring to this attribute type from code - only add handles; don’t remove them

bannable: bool

Whether Attributes of this type can be used to ban users. Users must provide such a bannable attribute.

identifying: bool

Whether Attributes of this type can be used to identify a users.

sources: Vec<SourceDetails>

The different ‘regular’ ways this attribute can be obtained via crate::api::auths::AuthStartEP.

Some attributes, like the pubhubs card attribute, can also be obtained in irregular ways.

not_addable_by_default: bool

If set, an instance of this attribute obtained by crate::api::auths::AuthStartEP can not be added to a user account. Pubhubs card attribute types have this flag set - to get an pubhubs card attribute instance that is addable, use crate::api::auths::CardEP.

Implementations

Source

impl Type

pub fn yivi_attr_type_ids( &self, ) -> impl Iterator<Item = &AttributeTypeIdentifier>

Iterates over all the yivi::AttributeTypeIdentifiers that can be used to obtain this attribite type.

pub(crate) fn filter_sources(&mut self, accept_source: impl Fn(Source) -> bool)

Removes the SourceDetails from Sources not accepted by accept_source.