pub struct AttrState {
pub attr: Id,
pub banned: bool,
pub may_identify_user: Option<Id>,
pub bans_users: HashSet<Id>,
}Expand description
State of an Attr according to pubhubs central.
Fields
attr: Idbanned: boolWhether this attribute has been banned.
may_identify_user: Option<Id>The user, if any, that this attribute can identify.
Only identifies the user if the user lists this attribute among its identifying attributes.
Once set, this should never be unset. This prevents impersonation of a user when they remove their id.
bans_users: HashSet<Id>The users that provided this attribute as bannable attribute. If this attribute gets banned, so will they.
Implementations